@@ -7,23 +7,26 @@ import sys
 import time
 
 # fmt: off
-_=(0,0)  # _____________________________________________________________________  hey there! if you are reading this, your python is too old to run copyparty without some help. Please use https://github.com/9001/copyparty/releases/latest/download/copyparty-sfx.py or the pypi package instead, or see https://github.com/9001/copyparty/blob/hovudstraum/docs/devnotes.md#building if you want to build it yourself :-)  ************************************************************************************************************************************************
+_:tuple[int,int]=(0,0)  # _____________________________________________________________________  hey there! if you are reading this, your python is too old to run copyparty without some help. Please use https://github.com/9001/copyparty/releases/latest/download/copyparty-sfx.py or the pypi package instead, or see https://github.com/9001/copyparty/blob/hovudstraum/docs/devnotes.md#building if you want to build it yourself :-)  ************************************************************************************************************************************************
 # fmt: on
 
 try:
-    TYPE_CHECKING = False
+    from typing import TYPE_CHECKING
 except:
     TYPE_CHECKING = False
 
+if True:
+    from typing import Any, Callable, Optional
+
 PY2 = sys.version_info < (3,)
 PY36 = sys.version_info > (3, 6)
 if not PY2:
-    unicode   = str
+    unicode: Callable[[Any], str] = str
 else:
     sys.dont_write_bytecode = True
     unicode = unicode  # type: ignore
 
-WINDOWS  = (
+WINDOWS: Any = (
     [int(x) for x in platform.version().split(".")]
     if platform.system() == "Windows"
     else False
@@ -83,7 +86,6 @@ web/md2.js
 web/mde.css
 web/mde.html
 web/mde.js
-web/msg.css
 web/msg.html
 web/opds.xml
 web/rups.css
@@ -130,7 +132,7 @@ RESM = {
 
 
 class EnvParams(object):
-    def __init__(self)  :
+    def __init__(self) -> None:
         self.t0 = time.time()
         self.mod = ""
         self.mod_ = ""
