@@ -437,7 +437,7 @@ Ls.nno = {
 	"fcp_both_b": '<a href="#" id="modal-ok">Kopiér</a><a href="#" id="modal-ng">Last opp</a>',
 
 	"mk_noname": "skriv inn eit namn i tekstboksa åt venstre først :p",
-	"nmd_i1": "leggja også til filendinga du vil, til dømes <code>.txt</code>", //m
+	"nmd_i1": "leggja også til filendinga du vil, til dømes <code>.md</code>", //m
 	"nmd_i2": "du kan berre laga <code>.md</code>-filer fordi du ikkje har delete-tilgang", //m
 
 	"tv_load": "Lastar inn tekstfil:\n\n{0}\n\n{1}% ({2} av {3} MiB lasta ned)",
