@@ -443,7 +443,7 @@ Ls.pol = {
 	"fcp_both_b": '<a href="#" id="modal-ok">Kopiuj</a><a href="#" id="modal-ng">Prześlij</a>',
 
 	"mk_noname": "wpisz nazwę do pola po lewej zanim to zrobisz :p",
-	"nmd_i1": "możesz też dodać wybrane rozszerzenie, np. <code>.txt</code>", //m
+	"nmd_i1": "możesz też dodać wybrane rozszerzenie, np. <code>.md</code>", //m
 	"nmd_i2": "możesz tworzyć tylko pliki <code>.md</code>, ponieważ nie masz uprawnień do usuwania", //m
 
 	"tv_load": "Wczytywanie pliku tekstowego:\n\n{0}\n\n{1}% (wczytano {2} z {3} MiB)",
