@@ -440,7 +440,7 @@ Ls.rus = {
 	"fcp_both_b": '<a href="#" id="modal-ok">Скопировать</a><a href="#" id="modal-ng">Загрузить</a>',
 
 	"mk_noname": "введите имя в текстовое поле слева перед тем, как это делать :p",
-	"nmd_i1": "вы также можете указать нужное расширение, например <code>.txt</code>", //m
+	"nmd_i1": "вы также можете указать нужное расширение, например <code>.md</code>", //m
 	"nmd_i2": "вы можете создавать только файлы <code>.md</code>, так как у вас нет разрешения на удаление", //m
 
 	"tv_load": "Загружаю текстовый документ:\n\n{0}\n\n{1}% ({2} из {3} МиБ загружено)",
