@@ -440,7 +440,7 @@ Ls.swe = {
 	"fcp_both_b": '<a href="#" id="modal-ok">Kopiera</a><a href="#" id="modal-ng">Ladda upp</a>',
 
 	"mk_noname": "skriv ett namn i fältet till vänster först :p",
-	"nmd_i1": "lägg också till filändelsen du vill ha, till exempel <code>.txt</code>", //m
+	"nmd_i1": "lägg också till filändelsen du vill ha, till exempel <code>.md</code>", //m
 	"nmd_i2": "du kan bara skapa <code>.md</code>-filer eftersom du inte har borttagningsbehörighet", //m
 
 	"tv_load": "Laddar textfil:\n\n{0}\n\n{1}% ({2} av {3} MiB laddat)",
