@@ -440,7 +440,7 @@ Ls.ukr = {
 	"fcp_both_b": '<a href="#" id="modal-ok">Скопіювати</a><a href="#" id="modal-ng">Завантажити</a>',
 
 	"mk_noname": "введіть ім'я в текстове поле зліва перед тим, як робити це :p",
-	"nmd_i1": "ви також можете додати потрібне розширення, наприклад <code>.txt</code>", //m
+	"nmd_i1": "ви також можете додати потрібне розширення, наприклад <code>.md</code>", //m
 	"nmd_i2": "ви можете створювати тільки файли <code>.md</code>, оскільки не маєте дозволу на видалення", //m
 
 	"tv_load": "Завантаження текстового документа:\n\n{0}\n\n{1}% ({2} з {3} MiB завантажено)",
